"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createServer = void 0;
const express_1 = __importDefault(require("express"));
const get_port_1 = __importDefault(require("get-port"));
const config_js_1 = require("./config.js");
const app = (0, express_1.default)();
app.use(express_1.default.json());
const createServer = async ({ config, serverPort, targetPort }) => {
    const port = await (0, get_port_1.default)({ port: serverPort });
    app.get('/up', (req, res) => {
        res.status(200).send({ status: 'ok' });
    });
    app.get('/health', async (req, res) => {
        try {
            await fetch(`http://localhost:${targetPort}`, {
                timeout: config_js_1.HEALTH_TIMEOUT,
                method: 'HEAD',
            });
            res.status(200).send({ status: 'ok' });
        }
        catch (error) {
            if (error?.response?.status) {
                res.status(200).send({ status: 'ok' });
            }
            else {
                res.status(500).send({ status: 'error', error });
            }
        }
    });
    app.post('/content-refresh', async (req, res) => {
        await fetch(`http://localhost:${targetPort}/__refresh`, {
            method: 'POST',
        });
        res.status(200).send({ status: 'ok' });
    });
    app.post('/git/pull', async (req, res) => {
        try {
            const { stdout, stderr, exitCode } = await config.utils.run('git', [
                'pull',
                '--rebase',
                '--autostash',
                '-Xtheirs',
                'origin',
                req.body?.branch || '',
            ]);
            if (exitCode === 0) {
                res.status(200).send({ status: 'ok', stdout });
            }
            else {
                res.status(500).send({ status: 'error', error: stderr, stdout, exitCode });
            }
        }
        catch (error) {
            console.log(error);
            res.status(500).send({ status: 'error', error });
        }
    });
    return new Promise((resolve) => {
        app.listen(port, () => {
            console.log('[dev-server-plugin] listening on port', port);
            resolve(port);
        });
    });
};
exports.createServer = createServer;
if (require.main === module) {
    (0, exports.createServer)({ serverPort: config_js_1.DEFAULT_SERVER_PORT, targetPort: config_js_1.DEFAULT_TARGET_PORT });
}
